/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the SCO ODT 110 keyboard.
 * By Steven W. Orr <steveo@world.std.com>.
 */

static const KeyCode sco110_codes [] = {

  /* Row 0 */
  8,
  66, 67, 68, 69,
  70, 71, 72, 73,
  74, 75, 94, 95,
  150, 77, 149,

  /* Row 2 */
  48, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
  137, 139, 141,
  76, 147, 62, 81,

  /* Row 3 */
  22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 50,
  138, 140, 142,
  78, 79, 80, 85,
  
  /* Row 4 */
  65, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 35,
  82, 83, 84,

  /* Row 5 */
  49, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
  145,
  86, 87, 88, 148,

  /* Row 6 */
  36,
  63, 64, 136,
  135,
  144, 146, 143,
  89, 90
};
